aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorNeels Hofmeyr <nhofmeyr@sysmocom.de>2015-10-12 14:00:21 +0200
committerHolger Hans Peter Freyther <holger@moiji-mobile.com>2015-10-12 14:10:27 +0200
commitb18e811e24464d9b50f21674246806c3b7c25030 (patch)
treec968708538c81aa9cd5f534b1e9f7e72f9a9120b
parent9b09738891770367f9878a1a4d1b83bc23217383 (diff)
gtp.h: rename gsn_t.dublicate to duplicate.
Fix spelling dublicate -> duplicate. This is potentially breaking API compat, but currently, no users of gsn_t.dublicate are known.
-rw-r--r--gtp/gtp.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/gtp/gtp.h b/gtp/gtp.h
index 76c967b..3ce89ed 100644
--- a/gtp/gtp.h
+++ b/gtp/gtp.h
@@ -276,7 +276,7 @@ struct gsn_t {
uint64_t tooshort; /* Number of too short headers 29.60 11.1.2 */
uint64_t unknown; /* Number of unknown messages 29.60 11.1.3 */
uint64_t unexpect; /* Number of unexpected messages 29.60 11.1.4 */
- uint64_t dublicate; /* Number of dublicate or unsolicited replies */
+ uint64_t duplicate; /* Number of duplicate or unsolicited replies */
uint64_t missing; /* Number of missing information field messages */
uint64_t incorrect; /* Number of incorrect information field messages */
uint64_t invalid; /* Number of invalid message format messages */